/**
 * NOTE: This component requires a 'data' property to be set in order
 *         to know which forms to check (guardedForms[]).
 */
import { Vue } from "vue-property-decorator";
import { Form } from "./types";
/**
 * Mixin to prevent leaving a form with unsaved changes (using routing)
 *
 * The mixin provides several properties to assist with prompting the user
 *   to confirm/cancel form navigation.
 */
declare class FormGuardMixin extends Vue {
    formLeaveCallback: ((leave: boolean) => void) | null;
    get forms(): Form[];
    /**
     * Whether the form leave guard is active
     *
     * This can be used to control a confirmation dialog, etc...
     */
    get isFormGuardActive(): boolean;
    /**
     * Set whether the form leave guard is active
     *
     * NOTE: This should not be set manually but as part of confirmation process!
     */
    set isFormGuardActive(val: boolean);
    get onlyPrevent(): boolean;
    /**
     * Handler to determine whether the form navigation should be continued/cancelled
     * @param shouldLeave - Whether form navigation should continue (will reset form)
     *
     * NOTE: This will call the previously interupted "next" route method.
     */
    onFormLeave(shouldLeave: boolean): void;
    beforeRouteLeave(to: any, from: any, next: () => void): void;
}
export { FormGuardMixin };
